==> bui_component-0.0.47.tar.gz: example/lib/Screen/LoginScreen.dart <==
import 'package:bui_component/LoginScreenComponent.dart';
import 'package:bui_component/Utils/SystemUtils.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:toast/toast.dart';

import 'ForgotScreen.dart';
import 'SignUpScreen.dart';

class LoginScreen extends StatefulWidget {
  @override
  _LoginScreenState createState() => _LoginScreenState();
}

class _LoginScreenState extends State<LoginScreen> {
  final passwordController = TextEditingController();
  final emailController = TextEditingController();
  var _formKey = GlobalKey<FormState>();

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    //_onCountryChange(code);
    getStringValuesSF();
  }

  Color theme = AppColors.APP_COLOR_PRIMARY;
  SharedPreferences prefs;

  getStringValuesSF() async {
    prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString('stringValue');
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return LoginScreenComponent(
      backgroundPrimaryColor: theme,
      globalKey: _formKey,
      signInFunction: signInFunction,
      emailController: emailController,
      passwordController: passwordController,
      signUpFunction: signUpFunction,
      forgotFunction: forgotFunction,
    );
  }

  Future<void> signInFunction() async {
    final isValid = _formKey.currentState.validate();
    if (!isValid) {
      return;
    }
    _formKey.currentState.save();

    if (SystemUtils.hasMatchEmail(emailController.text.toString())) {
      Toast.show("Successfully Login", context);
    }
  }

  Future<void> forgotFunction() async {
    Navigator.push(context,
        MaterialPageRoute(builder: (BuildContext context) => ForgotScreen()));
  }

  Future<void> signUpFunction() async {
    Navigator.pushReplacement(context,
        MaterialPageRoute(builder: (BuildContext context) => SignUpScreen()));
  }
}

==> bui_component-0.0.56.tar.gz: example/lib/Screen/LoginScreen.dart <==
import 'package:bui_component/LoginScreenComponent.dart';
import 'package:bui_component/Utils/SystemUtils.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:toast/toast.dart';
import 'package:example/Constants/AppStrings.dart';
import 'ForgotScreen.dart';
import 'SignUpScreen.dart';
import 'package:example/Constants/ImageAssets.dart';

class LoginScreen extends StatefulWidget {
  @override
  _LoginScreenState createState() => _LoginScreenState();
}

class _LoginScreenState extends State<LoginScreen> {
  final passwordController = TextEditingController();
  final emailController = TextEditingController();
  var _formKey = GlobalKey<FormState>();

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    //_onCountryChange(code);
    getStringValuesSF();
  }

  Color theme = AppColors.APP_COLOR_PRIMARY;
  SharedPreferences prefs;

  getStringValuesSF() async {
    prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        theme = Color(colorCodeInt);
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return LoginScreenComponent(
      backgroundPrimaryColor: theme,
      globalKey: _formKey,
      signInFunction: signInFunction,
      emailController: emailController,
      passwordController: passwordController,
      signUpFunction: signUpFunction,
      forgotFunction: forgotFunction,
      imageLogo: Container(
        height: MediaQuery.of(context).size.height * 0.3,
        width: MediaQuery.of(context).size.width * 0.5,
        child: CircleAvatar(
          radius: 20,
          backgroundColor: Colors.white,
          child: Container(
            padding: EdgeInsets.all(20),
            child: Image.asset(
              ImageAssets.LOGO_WITH_NAME,
              height: MediaQuery.of(context).size.height * 0.2,
            ),
          ),
        ),
      ),
    );
  }

  Future<void> signInFunction() async {
    final isValid = _formKey.currentState.validate();
    if (!isValid) {
      return;
    }
    _formKey.currentState.save();

    if (SystemUtils.hasMatchEmail(emailController.text.toString())) {
      Toast.show("Successfully Login", context);
    }
  }

  Future<void> forgotFunction() async {
    Navigator.push(context,
        MaterialPageRoute(builder: (BuildContext context) => ForgotScreen()));
  }

  Future<void> signUpFunction() async {
    Navigator.pushReplacement(context,
        MaterialPageRoute(builder: (BuildContext context) => SignUpScreen()));
  }
}
